﻿using System;
using Microsoft.AspNetCore.Identity;
using Microsoft.EntityFrameworkCore.Internal;

namespace Quibbler.Persistence
{
    public static class DbInitializer
    {
        public static void Initialize(QuibblerContext context, UserManager<User> userManager)
        {
            context.Database.EnsureCreated();

            if (context.News.Any())
                return;

            var users = new User[]
            {
                new User {UserName = "jani", Email = "kiss.janos@ote.op"},
                new User {UserName = "jani2", Email = "nagy.janos@ote.op"},
                new User {UserName = "pali", Email = "rugka.pal@ote.op"},
                new User {UserName = "aron", Email = "barmi.aron@ote.op"},
                new User {UserName = "dori", Email = "virra.dora@ote.op"},
                new User {UserName = "BATMAN", Email = "bruce.wayne@gotham.com"}
            };
            foreach (var user in users)
            {
                userManager.CreateAsync(user, user.UserName).Wait();
                // a jelszó egyezik a felhasználónévvel az egyszerűség kedvéért
            }

            var posts = new Post[]
            {
                // thread 1
                new Post
                {
                    Content = "Már megint nem lehet belépni az Uránusz tanulmányi rendszerbe!",
                    Timestamp = new DateTime(2019, 12, 15, 10, 0, 0),
                    User = users[0]
                },
                new Post
                {
                    Content = "Nekem sem működik!",
                    Timestamp = new DateTime(2019, 12, 15, 10, 5, 0),
                    User = users[1]
                },
                new Post
                {
                    Content = "Biztosan megint túlterhelt a vizsgajelentkezés miatt.",
                    Timestamp = new DateTime(2019, 12, 15, 10, 8, 0),
                    User = users[0]
                },
                new Post
                {
                    Content = "Most már működik.",
                    Timestamp = new DateTime(2019, 12, 15, 10, 20, 0),
                    User = users[2]
                },

                // thread 2
                new Post
                {
                    Content = "Azt a hír hallottam, hogy más egyetemek sikerén felbuzdulva a következő félévtől az előadások látogatáskötelesek lesznek!",
                    Timestamp = new DateTime(2019, 12, 18, 20, 3, 5),
                    User = users[3]
                },
                new Post
                {
                    Content = "Úgysem tudnák ellenőrizni.",
                    Timestamp = new DateTime(2019, 12, 18, 22, 10, 3),
                    User = users[4]
                },
                new Post
                {
                    Content = "Nem olvashatnak minden előadás elején katalógust.",
                    Timestamp = new DateTime(2019, 12, 19, 9, 10, 11),
                    User = users[2]
                },

                // thread 3
                new Post
                {
                    Content = "Feltöltöttem a tegnapi vizsga feladatsort Időutazás speciből. http://batshare.op/exam.pdf",
                    Timestamp = new DateTime(2019, 12, 17, 15, 32, 47),
                    User = users[5]
                },
                new Post
                {
                    Content = "You are not the hero we need, but the hero we deserve.",
                    Timestamp = new DateTime(2019, 12, 17, 16, 0, 0),
                    User = users[0]
                },

                // thread 4
                new Post
                {
                    Content = "Elhagytam egy sálat a Délkeleti Épületben. Nem látta valaki?",
                    Timestamp = new DateTime(2019, 12, 13, 12, 0, 0),
                    User = users[1]
                },

                // thread 5
                new Post
                {
                    Content = "Kikerültek a jövő féléves ösztöndíj felhívások az egyetem honlapjára, érdemes megnézni őket.",
                    Timestamp = new DateTime(2019, 12, 16, 14, 30, 0),
                    User = users[4]
                }

            };
            posts[1].ReplyFor = posts[0];
            posts[2].ReplyFor = posts[1];
            posts[3].ReplyFor = posts[0];

            posts[5].ReplyFor = posts[4];
            posts[6].ReplyFor = posts[4];

            posts[8].ReplyFor = posts[7];

            context.News.AddRange(posts);

            var favorites = new Favorite[]
            {
                new Favorite {Post = posts[0], User = users[1]},
                new Favorite {Post = posts[0], User = users[2]},
                new Favorite {Post = posts[0], User = users[3]},
                new Favorite {Post = posts[1], User = users[0]},
                new Favorite {Post = posts[3], User = users[0]},
                new Favorite {Post = posts[3], User = users[1]},
                new Favorite {Post = posts[3], User = users[4]},
                new Favorite {Post = posts[4], User = users[0]},
                new Favorite {Post = posts[4], User = users[1]},
                new Favorite {Post = posts[6], User = users[4]},
                new Favorite {Post = posts[6], User = users[3]},
                new Favorite {Post = posts[7], User = users[0]},
                new Favorite {Post = posts[7], User = users[1]},
                new Favorite {Post = posts[7], User = users[2]},
                new Favorite {Post = posts[7], User = users[3]},
                new Favorite {Post = posts[7], User = users[4]},
                new Favorite {Post = posts[8], User = users[1]},
                new Favorite {Post = posts[8], User = users[3]},
                new Favorite {Post = posts[10], User = users[3]},
            };

            context.Favorites.AddRange(favorites);

            context.SaveChanges();
        }
    }
}
